@@ -24,6 +24,7 @@ from jaxopt._src.armijo_sgd import ArmijoSGD
 from jaxopt._src.backtracking_linesearch import BacktrackingLineSearch
 from jaxopt._src.bisection import Bisection
 from jaxopt._src.block_cd import BlockCoordinateDescent
+from jaxopt._src.cd_qp import BoxCDQP
 from jaxopt._src.cvxpy_wrapper import CvxpyQP
 from jaxopt._src.eq_qp import EqualityConstrainedQP
 from jaxopt._src.fixed_point_iteration import FixedPointIteration
@@ -31,6 +32,7 @@ from jaxopt._src.gauss_newton import GaussNewton
 from jaxopt._src.gradient_descent import GradientDescent
 from jaxopt._src.iterative_refinement import IterativeRefinement
 from jaxopt._src.lbfgs import LBFGS
+from jaxopt._src.levenberg_marquardt import LevenbergMarquardt
 from jaxopt._src.mirror_descent import MirrorDescent
 from jaxopt._src.nonlinear_cg import NonlinearCG
 from jaxopt._src.optax_wrapper import OptaxSolver
