@@ -17,6 +17,8 @@
 # TODO(fllinares): add support for `LinearConstraint`s.
 # TODO(fllinares): add support for methods requiring Hessian / Hessian prods.
 # TODO(fllinares): possibly hardcode `dtype` attribute, as likely useless.
+# TODO(pedregosa): add a 'maxiter' keyword option for all wrappers,
+#   currently only ScipyMinimize exposes this option.
 """
 
 import abc
@@ -200,6 +202,8 @@ class ScipyWrapper(base.Solver):
 
   Attributes:
     method: the `method` argument for `scipy.optimize`.
+    maxiter: Maximum number of iterations to perform. Depending on the method,
+      each iteration may use several function evaluations.
     dtype: if not None, cast all NumPy arrays to this dtype. Note that some
       methods relying on FORTRAN code, such as the `L-BFGS-B` solver for
       `scipy.optimize.minimize`, require casting to float64.
@@ -267,6 +271,7 @@ class ScipyMinimize(ScipyWrapper):
   fun: Callable = None
   tol: Optional[float] = None
   options: Optional[Dict[str, Any]] = None
+  maxiter: int = 500
 
   def optimality_fun(self, sol, *args, **kwargs):
     """Optimality function mapping compatible with `@custom_root`."""
@@ -289,6 +294,7 @@ class ScipyMinimize(ScipyWrapper):
 
     res = osp.optimize.minimize(scipy_fun, jnp_to_onp(init_params, self.dtype),
                                 jac=True,
+                                tol=self.tol,
                                 bounds=bounds,
                                 method=self.method,
                                 options=self.options)
@@ -328,6 +334,12 @@ class ScipyMinimize(ScipyWrapper):
       self._grad_fun = jax.jit(self._grad_fun)
       self._value_and_grad_fun = jax.jit(self._value_and_grad_fun)
 
+    if self.options is None:
+      self.options = {}
+    if 'maxiter' in self.options:
+      raise ValueError("Cannot pass maxiter through options dictionary, use maxiter keyword argument instead.")
+    self.options['maxiter'] = self.maxiter
+
 
 @dataclass(eq=False)
 class ScipyBoundedMinimize(ScipyMinimize):
@@ -438,13 +450,20 @@ class ScipyRootFinding(ScipyWrapper):
                                          pytree_topology,
                                          self.dtype)
 
-    def scipy_fun(x_onp: onp.ndarray) -> Tuple[onp.ndarray, onp.ndarray]:
+    def scipy_fun(x_onp: onp.ndarray, scipy_args: Any) -> Tuple[onp.ndarray, onp.ndarray]:
+      # scipy_args is unused but must appear in the signature since
+      # the `args` argument passed to osp.optimize.root is not None.
+      del scipy_args  # unused
       x_jnp = onp_to_jnp(x_onp)
       value_jnp = self.optimality_fun(x_jnp, *args, **kwargs)
       jacs_jnp = self._jac_fun(x_jnp, *args, **kwargs)
       return jnp_to_onp(value_jnp, self.dtype), jac_jnp_to_onp(jacs_jnp)
 
+    # Argument `args` is unused but must be not None to ensure that some sanity checks are performed
+    # correctly in Scipy for optimizers that don't use the Jacobian (such as Broyden).
+    # See the related issue: https://github.com/google/jaxopt/issues/290
     res = osp.optimize.root(scipy_fun, jnp_to_onp(init_params, self.dtype),
+                            args=(None,),  
                             jac=True,
                             tol=self.tol,
                             method=self.method,
